# QUARK-plugin-myqlm

This QUARK-plugin provides access to myQLM (https://myqlm.github.io/) functionalities.

Access to the myQLM QPU simulators is provided via the QUARK-module "MyQLMDigitalQPU".

As an example application you can use the GHZ module from QUARK-plugin-ghz with the mapping "GHZtoQaptivaCircuit". A corresponding QUARK-configuration is given in configs/ghz_demo_cfg.yml.
